﻿using DynamicXamlLoadAndPrint;
using System.IO;
using System.Reflection.Metadata;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Markup;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Xml;
using System.Xml.Linq;

namespace MultiPage
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        PrintDialog printDialog = new PrintDialog();

        public MainWindow()
        {
            InitializeComponent();
        }


        /// <summary>
        /// 手动创建多页
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Button_Click_1(object sender, RoutedEventArgs e)
        {
            FixedDocument document = new FixedDocument();
            //设置纸张大小
            document.DocumentPaginator.PageSize = new Size(600, 800);

            //增加一页
            FixedPage page1 = new FixedPage();
            page1.Width = document.DocumentPaginator.PageSize.Width;
            page1.Height = document.DocumentPaginator.PageSize.Height;

            //增加一个图像显示到第一页
            Image image = new Image();
            image.Width = document.DocumentPaginator.PageSize.Width;
            image.Height = document.DocumentPaginator.PageSize.Height;
            image.Stretch = Stretch.Uniform;
            image.Source = new BitmapImage(new Uri("https://myfreetime.cn/usr/uploads/2024/4/%E6%B8%85%E5%B9%B3%E8%B0%83%C2%B7%E5%90%8D%E8%8A%B1%E5%80%BE%E5%9B%BD%E4%B8%A4%E7%9B%B8%E6%AC%A2/jk.jpg"));
            page1.Children.Add(image);

            //添加页到Document中
            PageContent page1Content = new PageContent();
            ((IAddChild)page1Content).AddChild(page1);
            document.Pages.Add(page1Content);

            FixedPage page2 = new FixedPage();
            page2.Width = document.DocumentPaginator.PageSize.Width;
            page2.Height = document.DocumentPaginator.PageSize.Height;
            TextBlock page2Text = new TextBlock();
            page2Text.Text = "HelloWorld";
            page2Text.Width = document.DocumentPaginator.PageSize.Width;
            page2Text.Height = document.DocumentPaginator.PageSize.Height;
            page2Text.FontSize = 40;
            page2Text.HorizontalAlignment = HorizontalAlignment.Center;
            page2Text.VerticalAlignment = VerticalAlignment.Center;
            page2.Children.Add(page2Text);
            PageContent page2Content = new PageContent();
            ((IAddChild)page2Content).AddChild(page2);
            document.Pages.Add(page2Content);

            this.viewer.Document = document;

            printDialog.PrintDocument(document.DocumentPaginator, "");
        }

        /// <summary>
        /// 从模板文件加载 
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Button_Click(object sender, RoutedEventArgs e)
        {
            //加载XAML
            var xaml = System.IO.File.ReadAllText(Environment.CurrentDirectory + "\\Template.xaml");
            StringReader sr = new StringReader(xaml);
            XDocument doc = XDocument.Load(sr);
            var pages = doc.Root.Elements();

            FixedDocument document = new FixedDocument();
            //设置纸张大小
            document.DocumentPaginator.PageSize = new Size(600, 800);

            //动态读取第一页
            StringReader xamlReader = new StringReader(pages.ElementAt(0).ToString());
            XmlReader xmlReader = XmlReader.Create(xamlReader);
            FixedPage page1 = (FixedPage)XamlReader.Load(xmlReader);
            var page1Container = page1.Children[0] as Grid;
            page1Container.Width = document.DocumentPaginator.PageSize.Width;
            page1Container.Height = document.DocumentPaginator.PageSize.Height;
            ReportViewModel reportModel = new ReportViewModel();
            reportModel.Image = "https://myfreetime.cn/usr/uploads/2024/4/%E6%B8%85%E5%B9%B3%E8%B0%83%C2%B7%E5%90%8D%E8%8A%B1%E5%80%BE%E5%9B%BD%E4%B8%A4%E7%9B%B8%E6%AC%A2/jk.jpg";
            reportModel.Text = "HelloWorld";
            reportModel.Width = 300;
            reportModel.Height = 600;
            //设置ViewModel
            page1.DataContext = reportModel;

            //添加页到Document中
            PageContent page1Content = new PageContent();
            ((IAddChild)page1Content).AddChild(page1);
            document.Pages.Add(page1Content);

            //动态读取第二页
            StringReader xamlReader2 = new StringReader(pages.ElementAt(1).ToString());
            XmlReader xmlReader2 = XmlReader.Create(xamlReader2);
            FixedPage page2 = (FixedPage)XamlReader.Load(xmlReader2);
            var page2Container = page2.Children[0] as Grid;
            page2Container.Width = document.DocumentPaginator.PageSize.Width;
            page2Container.Height = document.DocumentPaginator.PageSize.Height;
            ReportViewModel reportModel2 = new ReportViewModel();
            reportModel2.Image = "https://myfreetime.cn/usr/uploads/2024/4/%E6%B8%85%E5%B9%B3%E8%B0%83%C2%B7%E5%90%8D%E8%8A%B1%E5%80%BE%E5%9B%BD%E4%B8%A4%E7%9B%B8%E6%AC%A2/jk2.jpg";
            reportModel2.Text = "HelloWorld";
            //设置ViewModel
            page2.DataContext = reportModel2;

            //添加页到Document中
            PageContent page2Content = new PageContent();
            ((IAddChild)page2Content).AddChild(page2);
            document.Pages.Add(page2Content);

            viewer.Document = document;
            sr.Dispose();
            xamlReader.Dispose();
            xamlReader2.Dispose();
        }
    }
}